%==============================================================================%
% `basi.cls'                                                                   %
% ==========                                                                   %
%                                                                              %
% LaTeX2e Document Class for the Bulletin of the Astronomical Society of India %
%                                                                              %
% Copyright Astronomical Society of India 2001, 2003, 2011                     %
%                                                                              %
% Author: (Version 1.0)                                                        %
%         Dipankar Bhattacharya                                                %
%           Raman Research Institute, Bangalore 560080, India.                 %
%                                                                              %
%         (Version 2.0)                                                        %
%         Dave Green                                                           %
%           Cavendish Laboratory, 19 J J Thomson Ave, Cambridge CB3 0HE, U.K.  %
%                                                                              %
% Version 1.0      17 Apr 2003                                                 %
% Version 2.0       9 Feb 2011, tidied up slightly (added usenatbib and        %
%                               conference options, continuedfigures, and      %
%                               asi-logo on the first page)                    %
% Version 2.1      29 Jan 2012, minor updates/clarifications                   %
%==============================================================================%
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
%
\ProvidesClass{basi}[2012/01/29
   V2.1 Bulletin of the Astronomical Society of India]
%
\newif\ifbasi@doublespacing\basi@doublespacingfalse
\newif\ifbasi@landscape\basi@landscapefalse
\newif\ifbasi@natbib\basi@natbibfalse
\newif\ifbasi@conference\basi@conferencefalse
%
\DeclareOption{a4paper}{\setlength\paperheight{297mm}%
   \setlength\paperwidth{210mm}}
\DeclareOption{draft}{\setlength\overfullrule{5pt}\basi@doublespacingtrue}
\DeclareOption{final}{\setlength\overfullrule{0pt}\basi@doublespacingfalse}
\DeclareOption{doublespacing}{\basi@doublespacingtrue}
\DeclareOption{landscape}{\basi@landscapetrue}
\DeclareOption{portrait}{\basi@landscapefalse}
\DeclareOption{twoside}{\@twosidetrue\@mparswitchtrue}
\DeclareOption{leqno}{\input{leqno.clo}}
\DeclareOption{fleqn}{\input{fleqn.clo}}
\DeclareOption{usenatbib}{\basi@natbibtrue}
\DeclareOption{conference}{\basi@conferencetrue}
%
\ExecuteOptions{a4paper,portrait,twoside,final}
\ProcessOptions
%
% Trailing dot added to section numbers...
%
\newif\if@levelone
\def\@startsection#1#2#3#4#5#6{\if@noskipsec \leavevmode \fi
  \par \@tempskipa #4\relax
  \@afterindenttrue
  \ifnum #2=\@ne
    \global\@levelonetrue
  \else
    \global\@levelonefalse
  \fi
  \ifdim\@tempskipa < 0pt \@tempskipa -\@tempskipa \@afterindentfalse\fi
  \if@nobreak \everypar{}\else
    \addpenalty{\@secpenalty}\addvspace{\@tempskipa}\fi \@ifstar
    {\@ssect{#3}{#4}{#5}{#6}}{\@dblarg{\@sect{#1}{#2}{#3}{#4}{#5}{#6}}}}
\def\@seccntformat#1{\csname the#1\endcsname\if@levelone.\fi\hskip 1em}
%
\def\@sect#1#2#3#4#5#6[#7]#8{%
  \ifnum #2>\c@secnumdepth
    \def\@svsec{}%
  \else
    \refstepcounter{#1}%
    \let\@@protect\protect
    \def\protect{\noexpand\protect\noexpand}%
    \edef\@svsec{\@seccntformat{#1}}%
    \let\protect\@@protect
  \fi
  \@tempskipa #5\relax
  \ifdim\@tempskipa > 0pt
    \begingroup #6\relax
      \@hangfrom{\hskip #3\relax\@svsec}{\interlinepenalty \@M #8\par}%
    \endgroup
    \csname #1mark\endcsname{#7}%
  \else
    \def\@svsechd{#6\hskip #3\relax %
      \@svsec #8 \csname #1mark\endcsname {#7}%
    }\fi%
  \@xsect{#5}}
%
\lineskip 1pt
\normallineskip 1pt
%
\ifbasi@doublespacing
  \def\baselinestretch{1.7}
\else
  \def\baselinestretch{1.0}
\fi
%
\renewcommand\normalsize{%
  \@setfontsize\normalsize{10}{12}%
  \abovedisplayskip 10pt plus 2pt minus 5pt
  \belowdisplayskip \abovedisplayskip
  \abovedisplayshortskip 0pt plus 3pt
  \belowdisplayshortskip 6pt plus 3pt minus 3pt
  \let\@listi\@listI}
\normalsize
\newcommand\small{%
  \@setfontsize\small{9}{11}%
  \abovedisplayskip 8.5 pt plus 3pt minus 4pt
  \belowdisplayskip \abovedisplayskip
  \abovedisplayshortskip 0pt plus 2pt
  \belowdisplayshortskip 4pt plus 2pt minus 2pt
  \def\@listi{\leftmargin\leftmargini
    \topsep 4pt-\parskip plus 2pt minus 2pt
    \parsep 2pt plus 1pt minus 1pt
    \itemsep \parsep}}
\newcommand\footnotesize{%
  \@setfontsize\footnotesize{8}{9.5}%
  \abovedisplayskip 6pt plus 2pt minus 4pt
  \belowdisplayskip \abovedisplayskip
  \abovedisplayshortskip 0pt plus 1pt
  \belowdisplayshortskip 3pt plus 1pt minus 2pt
  \def\@listi{\leftmargin\leftmargini
    \topsep 3pt-\parskip plus 1pt minus 1pt
    \parsep 2pt plus 1pt minus 1pt
    \itemsep \parsep}}
\newcommand\scriptsize{\@setfontsize\scriptsize\@viipt\@viiipt}
\newcommand\tiny{\@setfontsize\tiny\@vpt\@vipt}
\newcommand\large{\@setfontsize\large\@xiipt{14}}
\newcommand\Large{\@setfontsize\Large\@xivpt{18}}
\newcommand\LARGE{\@setfontsize\LARGE\@xviipt{22}}
\newcommand\huge{\@setfontsize\huge\@xxpt{25}}
\newcommand\Huge{\@setfontsize\Huge\@xxvpt{30}}
\setlength\smallskipamount{3pt plus 1pt minus 1pt}
\setlength\medskipamount{6pt plus 2pt minus 2pt}
\setlength\bigskipamount{12pt plus 4pt minus 4pt}
%
% Margins modified...
%
\setlength\oddsidemargin{34pt}
\setlength\evensidemargin{34pt}
\setlength\marginparwidth{90pt}
\setlength\marginparsep{10pt}
\setlength\headheight{11pt}
\setlength\headsep{19pt}
\setlength\topskip{10pt}
\setlength\footskip{30pt}
%
% Sizes modified (slightly smaller for conference option)...
%
\ifbasi@landscape
  \ifbasi@conference
    \setlength\oddsidemargin{57pt}
    \setlength\evensidemargin{57pt}
    \setlength\textheight{340pt}
    \setlength\textwidth{532pt}
  \else
    \setlength\textheight{386pt}
    \setlength\textwidth{521pt}
  \fi
\else
  \ifbasi@conference
    \setlength\oddsidemargin{57pt}
    \setlength\evensidemargin{57pt}
    \setlength\textheight{532pt}
    \setlength\textwidth{340pt}
  \else
    \setlength\textheight{521pt}
    \setlength\textwidth{386pt}
  \fi
\fi
%
\setlength\maxdepth{0.5\topskip}
\setlength\topmargin{72pt}
\setlength\footskip{17pt}
\addtolength\textheight{\topskip}
\setlength\columnsep{10pt}
\setlength\columnseprule{0pt}
%
% Footnoteskip modified...
%
\setlength\footnotesep{7.7pt}
\setlength{\skip\footins}{20pt plus 12pt minus 1pt}
%
\setlength\floatsep{10pt plus 2pt minus 2pt}
\setlength\textfloatsep{12pt plus 2pt minus 4pt}
\setlength\intextsep{12pt plus 2pt minus 2pt}
%
% float fills 1fil for top/bottom, so can be picked up by rotating package
%
\setlength\@fptop{0pt plus 1fil}
\setlength\@fpsep{8pt plus 2fil}
\setlength\@fpbot{0pt plus 1fil}
%
\AtBeginDocument{\setlength\@fptop{0pt plus 0fil}}
\AtBeginDocument{\setlength\@fpbot{0pt plus 0fil}}
%
\setlength\marginparpush{5pt}
%
% Paragraphing glue and penalty modified
%
\newlength{\savparskip}
\newlength{\savparindent}
\setlength\parskip{11pt plus 0.1pt}
\setlength\parindent{17pt}
\setlength\partopsep{0pt plus 0.1pt}
\@lowpenalty 51
\@medpenalty 151
\@highpenalty 301
\@beginparpenalty -\@lowpenalty
\@endparpenalty -\@lowpenalty
\@itempenalty -\@lowpenalty
\clubpenalty=0
\widowpenalty=10000
%
\setcounter{secnumdepth}{3}
%
\def\appendix{\par
  \setcounter{section}{0}
  \setcounter{subsection}{0}
  \def\thesection{\Alph{section}}}
%
\leftmargini 2.5em
\leftmarginii 2.2em
\leftmarginiii 1.87em
\leftmarginiv 1.7em
\leftmarginv 1.0em
\leftmarginvi 1.0em
\leftmargin\leftmargini
\labelsep 0.5em
\labelwidth\leftmargini\advance\labelwidth-\labelsep
\def\@listI{\leftmargin\leftmargini
  \parsep 4pt plus 2pt minus 1pt
  \topsep 8pt plus 2pt minus 4pt
  \itemsep 4pt plus 2pt minus 1pt}
\let\@listi\@listI
\@listi
\def\@listii{\leftmargin\leftmarginii
  \labelwidth\leftmarginii\advance\labelwidth-\labelsep
  \topsep 4pt-\parskip plus 2pt minus 1pt
  \parsep 2pt plus 1pt minus 1pt
  \itemsep \parsep}
\def\@listiii{\leftmargin\leftmarginiii
  \labelwidth\leftmarginiii\advance\labelwidth-\labelsep
  \topsep 2pt-\parskip plus 1pt minus 1pt
  \parsep 0pt
  \partopsep 1pt plus 0pt minus 1pt
  \itemsep \topsep}
\def\@listiv{\leftmargin\leftmarginiv
  \labelwidth\leftmarginiv\advance\labelwidth-\labelsep}
\def\@listv{\leftmargin\leftmarginv
  \labelwidth\leftmarginv\advance\labelwidth-\labelsep}
\def\@listvi{\leftmargin\leftmarginvi
  \labelwidth\leftmarginvi\advance\labelwidth-\labelsep}
%
\relax
\def\labelenumi{\theenumi.}
\def\theenumi{\arabic{enumi}}
\def\labelenumii{(\theenumii)}
\def\theenumii{\alph{enumii}}
\def\p@enumii{\theenumi}
\def\labelenumiii{\theenumiii.}
\def\theenumiii{\roman{enumiii}}
\def\p@enumiii{\theenumi(\theenumii)}
\def\labelenumiv{\theenumiv.}
\def\theenumiv{\Alph{enumiv}}
\def\p@enumiv{\p@enumiii\theenumiii}
%
\def\labelitemi{$\bullet$}
\def\labelitemii{\bf --}
\def\labelitemiii{$\ast$}
\def\labelitemiv{$\cdot$}
%
\def\verse{\let\\=\@centercr
  \list{}{\itemsep 0pt \itemindent -1.5em\listparindent \itemindent
  \rightmargin\leftmargin\advance\leftmargin 1.5em}\item[]}
\let\endverse\endlist
\def\quotation{\list{}{\listparindent 1.5em
  \itemindent\listparindent
  \rightmargin\leftmargin \parsep 0.0pt plus 1.0pt}\item[]}
\let\endquotation=\endlist
\def\quote{\list{}{\rightmargin\leftmargin}\item[]}
\let\endquote=\endlist
\def\descriptionlabel#1{\hspace\labelsep \bf #1}
\def\description{\list{}{\labelwidth 0pt \itemindent-\leftmargin
  \let\makelabel\descriptionlabel}}
\let\enddescription\endlist
%
\def\theequation{\arabic{equation}}
%
\def\titlepage{\onecolumn\thispagestyle{empty}\c@page 0pt}
\def\endtitlepage{\newpage}
%
\renewcommand{\arraystretch}{1.05}
\arraycolsep 5.0pt
\tabcolsep 6.0pt
\arrayrulewidth 0.4pt
\doublerulesep 2.0pt
\tabbingsep\labelsep
%
\skip\@mpfootins=\skip\footins
\fboxsep=3.0pt
\fboxrule=0.4pt
%
\newcounter{part}
\newcounter{section}
\newcounter{subsection}[section]
\newcounter{subsubsection}[subsection]
\newcounter{paragraph}[subsubsection]
\newcounter{subparagraph}[paragraph]
%
\def\thepart{\Roman{part}}
%
\def\thesection{\arabic{section}}
\def\thesubsection{\thesection.\arabic{subsection}}
\def\thesubsubsection{\mbox{\rm \thesubsection.\arabic{subsubsection}}}
%
\def\theparagraph{\thesubsubsection.\arabic{paragraph}}
\def\thesubparagraph{\theparagraph.\arabic{subparagraph}}
%
% Sectioning style modified
%
\def\section{\@startsection{section}{1}{0pt}%
  {-3.5ex plus -1ex minus -.2ex}{1.5ex plus 0.2ex}{\reset@font\large\bf\center}}
\def\subsection{\@startsection{subsection}{2}{0pt}%
  {-3.25ex plus -1ex minus -.2ex}{1.2ex plus 0.2ex}{\reset@font\normalsize\bf}}
\def\subsubsection{\@startsection{subsubsection}{3}{0pt}%
  {-3.25ex plus -1ex minus -.2ex}{1.2ex plus 0.2ex}{\reset@font\normalsize\it}}
\def\paragraph{\@startsection{paragraph}{4}{0pt}{3.25ex plus 1ex minus 0.2ex}%
  {-1em}{\reset@font\normalsize\bf}}
\def\subparagraph{\@startsection{subparagraph}{4}{\parindent}%
  {3.25ex plus 1ex minus 0.2ex}{-1em}{\reset@font\normalsize\it\center}}
%
% thebibliography definition modified
%
\newcounter{dummy}
\newlength{\leftadvance}
\setlength{\leftadvance}{1em}
\def\thebibliography#1{\section*{References}\list
  {\mbox{}}{\usecounter{dummy}
  \leftmargin\leftadvance \itemindent-\leftadvance
  \labelwidth 0pt \itemsep 0pt}
  \reset@font\small
  \parindent 0pt \parskip 0pt plus 0.1pt \relax
  \def\newblock{\hskip 0.11em plus 0.33em minus 0.07em}
  \sloppy\clubpenalty4000\widowpenalty4000
  \sfcode`\.=1000\relax}
\let\endthebibliography=\endlist
%
\def\footnoterule{\kern-3pt \hrule width 60pt \kern 3pt}
\long\def\@makefntext#1{\parindent 1em\noindent
  \hbox to 1.8em{\hss$^{\@thefnmark}$}#1}
%
% Float fractions modified
%
\setcounter{topnumber}{2}
\setcounter{totalnumber}{4}
\setcounter{bottomnumber}{1}
\renewcommand{\topfraction}{0.8}
\renewcommand{\bottomfraction}{0.8}
\renewcommand{\textfraction}{0.2}
\renewcommand{\floatpagefraction}{0.8}
%
\DeclareOldFontCommand{\rm}{\normalfont\rmfamily}{\mathrm}
\DeclareOldFontCommand{\sf}{\normalfont\sffamily}{\mathsf}
\DeclareOldFontCommand{\tt}{\normalfont\ttfamily}{\mathtt}
\DeclareOldFontCommand{\bf}{\normalfont\bfseries}{\mathbf}
\DeclareOldFontCommand{\it}{\normalfont\itshape}{\mathit}
\DeclareOldFontCommand{\sl}{\normalfont\slshape}{\@nomath\sl}
\DeclareOldFontCommand{\sc}{\normalfont\scshape}{\@nomath\sc}
\DeclareRobustCommand*\cal{\@fontswitch\relax\mathcal}
\DeclareRobustCommand*\mit{\@fontswitch\relax\mathnormal}
%
% font size in figure caption changed to small
%
\def\@captionfont{\small}
%
% makecaption customized
%
\long\def\@makecaption#1#2{
  \vskip 10pt
  \setbox\@tempboxa\hbox{\@captionfont{\bf #1.} #2}
  \ifdim\wd\@tempboxa > \hsize {\@captionfont {\bf #1.} #2}\par \else \hbox
  to\hsize{\hfil\box\@tempboxa\hfil}
  \fi}
%
\newcounter{figure}
\def\thefigure{\@arabic\c@figure}
\def\fps@figure{tbp}
\def\ftype@figure{1}
\def\ext@figure{lof}
\def\fnum@figure{{Figure \thefigure}}
\def\figure{\@float{figure}}
\let\endfigure\end@float
\newcounter{table}
\def\thetable{\@arabic\c@table}
\def\fps@table{tbp}
\def\ftype@table{2}
\def\ext@table{lot}
\def\fnum@table{{Table \thetable}}
\def\table{\@float{table}}
\let\endtable\end@float
%
\def\thanks#1{\footnotemark\hbox{~}\begingroup
\def\protect{\noexpand\protect\noexpand}\xdef\@thanks{\@thanks
  \protect\footnotetext[\the\c@footnote]{#1}}\endgroup}
\def\@thanks{}
%
% V2.0+ updated to be compatible with array.sty...
%
\def\maketitle{\par
  \begingroup
  \def\thefootnote{\fnsymbol{footnote}}
  \def\@makefnmark{\hbox to 0pt{$^{\@thefnmark}$\hss}}
  \newpage
  \global\@topnum 0
  \@maketitle
  \ifbasi@conference
    \thispagestyle{asicfirst}
  \else
    \thispagestyle{basifirst}
  \fi
  \@thanks
  \endgroup
  \setcounter{footnote}{0}
  \let\maketitle\relax
  \let\@maketitle\relax
  \gdef\@author{}
  \gdef\@title{}
  \gdef\@thanks{}
  \let\thanks\relax}
%
\def\newauthor{\end{tabular}
  \setlength{\savparskip}{\parskip}\setlength{\parskip}{0pt}
  \setlength{\savparindent}{\parindent}\setlength{\parindent}{0pt}
  \par\begin{tabular}[t]{@{}l@{}}\let\\=\author@crone
  \setlength{\parskip}{\savparskip}\setlength{\parindent}{\savparindent}}
%
\def\@maketitle{\newpage
  \vspace*{20pt}
  {\raggedright \sloppy
  {\reset@font\Large\bf \@title \par}
  \vskip 7pt
  {\reset@font\large
  \begin{tabular}[t]{@{}l@{}}\let\\=\author@crone\@author
  \end{tabular}
  \par}
  \vskip 7pt}
  \par\noindent
  {\reset@font\small \@date \par}
  \vskip 6pt}
%
\def\author@crone{\tabularnewline[-1pt]
  \reset@font\small\it\let\\=\author@crtwo\ignorespaces}
%
\def\author@crtwo{\tabularnewline[-3pt]
  \reset@font\small\it\let\\=\author@crtwo\ignorespaces}
%
\def\abstract{\@abstract}
\def\endabstract{\endlist}
%
\def\@abstract{\list{}{%
  \leftmargin 42.5pt \listparindent 3em
  \itemindent 0pt \labelwidth 0pt \labelsep 0pt \rightmargin 0pt}\item[]
  \reset@font\normalsize{\bf Abstract.\ }}
%
\def\keywords{\@keywords}
\def\endkeywords{\endlist}
%
\def\@keywords{\list{}{%
  \leftmargin 42.5pt \listparindent 0em
  \itemindent 0pt \labelwidth 0pt \labelsep 0pt \rightmargin 0pt
  \parsep 0pt plus 1pt}\item[]
  \reset@font\normalsize{\it Keywords}~:}
%
\mark{{}{}}
\if@twoside
  \def\ps@headings{\let\@mkboth\markboth
  \def\@oddfoot{}\def\@evenfoot{}\def\@evenhead{\rm \thepage\hfil \sl
  \leftmark}\def\@oddhead{\hbox{}\sl \rightmark \hfil
  \rm\thepage}\def\sectionmark##1{\markboth{\uppercase{\ifnum \c@secnumdepth
  > 0
  \thesection\hskip 1em\relax \fi ##1}}{}}\def\subsectionmark##1{\markright
  {\ifnum \c@secnumdepth > \@ne
  \thesubsection\hskip 1em\relax \fi ##1}}}
  \else \def\ps@headings{\let\@mkboth\markboth
  \def\@oddfoot{}\def\@evenfoot{}\def\@oddhead{\hbox{}\sl \rightmark \hfil
  \rm\thepage}\def\sectionmark##1{\markright{\uppercase{\ifnum \c@secnumdepth
  > 0
  \thesection\hskip 1em\relax \fi ##1}}}}
\fi
\def\ps@myheadings{\let\@mkboth\@gobbletwo
  \def\@oddhead{\hbox{}\sl\rightmark \hfil
  \rm\thepage}\def\@oddfoot{}\def\@evenhead{\rm \thepage\hfil\sl\leftmark\hbox
  {}}\def\@evenfoot{}\def\sectionmark##1{}\def\subsectionmark##1{}}
%
% BASI page style for pages other than first page of article
%
\def\ps@basiheadings{\let\@mkboth\@gobbletwo
  \def\@oddhead{\hbox{}\hfill{\small \it\@shorttitle}\hfill\hbox{}\rm\thepage}
  \def\@oddfoot{}
  \def\@evenhead{\rm\thepage\hbox{}\hfill{\small \it\@shortauthor}\hfill\hbox{}}
  \def\@evenfoot{}
  \def\sectionmark##1{\markboth{##1}{}}
  \def\subsectionmark##1{\markright{##1}}}
%
\gdef\@author{\mbox{}}
\gdef\@shortauthor{}
\def\author{\@ifnextchar [{\@authortwo}{\@authorone}}
\def\@authortwo[#1]#2{\gdef\@author{#2}\gdef\@shortauthor{#1}}
\def\@authorone#1{\gdef\@author{#1}\gdef\@shortauthor{#1}}
\gdef\@title{\mbox{}}
\gdef\@shorttitle{}
\def\title{\@ifnextchar [{\@titletwo}{\@titleone}}
\def\@titletwo[#1]#2{\gdef\@title{#2}\gdef\@shorttitle{#1}}
\def\@titleone#1{\gdef\@title{#1}\gdef\@shorttitle{#1}}
%
\def\volume#1{\gdef\@volume{#1}}
\gdef\@volume{00}
\def\pubyear#1{\gdef\@pubyear{#1}}
\gdef\@pubyear{0000}
\def\pagerange#1{\gdef\@pagerange{#1}}
\gdef\@pagerange{000--000}
\def\journal#1{\gdef\@journal{#1}}
\gdef\@status{}
\gdef\@nostatus{}
\def\status#1{\gdef\@status{#1}}
%
\ifbasi@conference
  \gdef\@journal{{ASI Conference Series, \@pubyear, Vol.~\@volume},
    \ifx\@status\@nostatus pp~\@pagerange\else\@status\fi}
\else
  \gdef\@journal{{Bull.\ Astr.\ Soc.\ India} (\@pubyear) {\bf \@volume},
    \ifx\@status\@nostatus\@pagerange\else\@status\fi}
\fi
%
\def\conference#1{\gdef\@asictitle{#1}}
\gdef\@asictitle{International Workshop on Stellar Spectral Libraries}
\def\editors#1{\gdef\@asiceditors{#1}}
\let\editor=\editors
\gdef\@asiceditors{Editors: H. P. Singh \& Ph. Prugniel}
%
% first page style: V2.0+ requires graphicx package and
%                   asi-logo.eps (or asi-logo.pdf)
%
\usepackage{graphicx}
\def\ps@basifirst{\let\@mkboth\@gobbletwo
  \def\@oddhead{\small\@journal\hfil\hbox{\logobox}}
  \def\@oddfoot{}
  \def\@evenhead{\small\@journal\hfil}
  \def\@evenfoot{\hfil \rm\thepage}}
%
% V2.0+ added logo...
%
\def\ps@asicfirst{\let\@mkboth\@gobbletwo
  \def\@oddhead{\hbox{\asicbox}\hfil\hbox{\logobox}}
  \def\@oddfoot{}
  \def\@evenhead{\small\@journal\hfil}
  \def\@evenfoot{\hfil \rm\thepage}}
%
\def\asicbox{\vbox to 0pt{\vskip-8pt\vbox{\let\\=\newline
  \small{\em \@asictitle}\\\@journal\\\@asiceditors}\vss}}
%
\def\logobox{\hbox to 0pt{\hskip-15mm\vbox to 0pt{
  \vss\hbox{\includegraphics[width=20mm]{asi-logo}}\ifbasi@conference
    \vskip-17mm\else\vskip-12mm\fi}\hss}}
%
\def\today{\number\year\ \ifcase\month\or
  January\or February\or March\or April\or May\or June\or
  July\or August\or September\or October\or November\or December
  \fi\ \number\day}
%
\ps@basiheadings
\pagenumbering{arabic}
\onecolumn
\if@twoside\else\raggedbottom\fi
%
% V2.0 added ...
%
\def\continuedfigure{\addtocounter{figure}{-1}\@float{figure}}
\let\endcontinuedfigure\end@float
%
\ifbasi@natbib%
  \usepackage[authoryear,longnamesfirst]{natbib}
  \def\newblock{\hskip 0.10em plus 0.15em minus 0.05em}
  \setlength{\bibsep}{0pt}
  \bibpunct{(}{)}{;}{a}{}{,}
%
\setlength{\bibhang}{1em}
\setlength{\leftadvance}{1em}
%------------------------------------------------------------------------------%
% fixserial.sty                                                                %
% -------------                                                                %
% Hack to natbib to remove serial comma from three author papers (as ADS       %
% produces these as "One, Two, \& Three").                                     %
%                                                                              %
% Dave Green -- 2011 January 19th                                              %
%------------------------------------------------------------------------------%
\def\splitintotwo[#1, \& #2]{\gdef\oneoftwo{#1}\gdef\twooftwo{#2}}
\def\endtest{EndAuthorList}
\def\checkifthree#1{\splitintotwo[#1, \& EndAuthorList]
  \ifx\twooftwo\endtest
    \gdef\AuthorNames{#1}
  \else
%    \immediate\write16{**Removing serial comma for three author paper**}
    \splitintotwo[#1]
    \gdef\AuthorNames{\oneoftwo\ \& \twooftwo}
  \fi}
\renewcommand\NAT@wrout[5]{\checkifthree{#3}\xdef\FirstNames{\AuthorNames}
  \checkifthree{#4}\xdef\SecondNames{\AuthorNames}
  \if@filesw{\let\protect\noexpand\let~\relax\immediate
  \write\@auxout{\string\bibcite{#5}{{#1}{#2}{{\FirstNames}}{{\SecondNames}}}}}
\fi\ignorespaces}
%------------------------------------------------------------------------------%
\fi
%==============================================================================%
\endinput
